@@ -18,6 +18,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "config.h"
+
 #include <string.h>
 
 #include <glib.h>
@@ -27,33 +29,25 @@
 #include <gconf/gconf-client.h>
 
 #include <libosso.h>
-
 #include <hildon/hildon.h>
 #include <hildon-extras/he-about-dialog.h>
 
 #ifdef WITH_SHARING
-
-#ifdef WITH_SHARING_H
 #include <sharingdialog/sharing-dialog.h>
 #endif
 
-#else
-void sharing_dialog_with_file(osso_context_t *osso, GtkWindow *parent, const gchar *uri);
-#endif
-
 #include <dicto/dicto.h>
 #include <dicto/dicto-ui.h>
-#include "config.h"
 
 /* #define PHONE_SRC "liveadder name=phonemixer ! pulsesrc device=sink.hw0.monitor ! phonemixer. pulsesrc device=source.hw0 ! phonemixer." */
-#define PHONE_SRC "adder name=phonemixer pulsesrc device=sink.hw0.monitor ! queue ! phonemixer. pulsesrc device=source.hw0 ! queue ! phonemixer. phonemixer. ! queue"
+#define PHONE_SRC "adder name=phonemixer ! pulsesrc device=sink.hw0.monitor ! queue ! phonemixer. pulsesrc device=source.hw0 ! audioamplify amplification=1.5 ! queue ! phonemixer. phonemixer. ! queue"
 #define SYSTEM_SRC "pulsesrc device=sink.hw0.monitor ! audioconvert ! queue "
 
 typedef enum {
 	SRC_MIC=0,
 	SRC_PHONE=1,
 	SRC_SYSTEM=2,
-	SRC_END=999
+	SRC_MAX=3
 } myDSrcId;
 
 typedef struct _MyDicto MyDicto;
@@ -61,12 +55,13 @@ struct _MyDicto {
 	HildonProgram *program;
 	HildonWindow *window;
 	osso_context_t *osso;
+	GConfClient *client;
 	GtkWidget *dw;
 	GtkWidget *source_button, *sharing_button, *format_button, *about_button;
 	Dicto *d, *dm, *dp;
+	gint src_id;
 	GtkTreeModel *formats;
-	DictoFormats f_mic;
-	DictoFormats f_phone;
+	DictoFormats df[SRC_MAX];
 	gchar *sink;
 	gchar *mic_src;
 	gchar *phone_src;
@@ -85,7 +80,7 @@ static MyDictoSrc sources[]={
 	{ SRC_MIC,	"Microphone", AUDIO_SRC },
 	{ SRC_PHONE,	"Phone", PHONE_SRC },
 	{ SRC_SYSTEM,	"System", SYSTEM_SRC },
-	{ SRC_END,	NULL, NULL }
+	{ SRC_MAX,	NULL, NULL }
 };
 
 #define MYDICTO_GCONF_PATH "/apps/mydicto"
@@ -95,11 +90,13 @@ static MyDictoSrc sources[]={
 static void
 mydicto_gconf_store(MyDicto *md)
 {
-GConfClient *client;
+if (gconf_client_set_int(md->client, MYDICTO_GCONF_AUDIO_FORMAT_MIC, md->df[SRC_MIC], NULL)==FALSE)
+	g_warning("Failed to store mic format");
+if (gconf_client_set_int(md->client, MYDICTO_GCONF_AUDIO_FORMAT_PHONE, md->df[SRC_PHONE], NULL)==FALSE)
+	g_warning("Failed to store phone format");
 
-client=gconf_client_get_default();
-gconf_client_set_int(client, MYDICTO_GCONF_AUDIO_FORMAT_MIC, md->f_mic, NULL);
-gconf_client_set_int(client, MYDICTO_GCONF_AUDIO_FORMAT_PHONE, md->f_phone, NULL);
+g_debug("SMICF: %d", md->df[SRC_MIC]);
+g_debug("SPHOF: %d", md->df[SRC_PHONE]);
 }
 
 static gboolean
@@ -165,6 +162,7 @@ dicto_stop_cb(Dicto *d, gpointer data)
 {
 gtk_widget_show(mapp.sharing_button);
 gtk_widget_show(mapp.format_button);
+hildon_gtk_window_set_do_not_disturb(mapp.window, FALSE);
 hildon_banner_show_information(GTK_WIDGET(mapp.window), "", _("Stopped"));
 return FALSE;
 }
@@ -183,6 +181,7 @@ dicto_recording_cb(Dicto *d, gpointer data)
 {
 gtk_widget_hide(mapp.sharing_button);
 gtk_widget_hide(mapp.format_button);
+hildon_gtk_window_set_do_not_disturb(mapp.window, TRUE);
 hildon_banner_show_information(GTK_WIDGET(mapp.window), "", _("Recording"));
 return FALSE;
 }
@@ -191,8 +190,9 @@ return FALSE;
  ** mydicto callbacks
  **/
 
-#define URL_MYDICTO "http://maemo.tal.org/"
+#define URL_MYDICTO "http://maemo.tal.org/index.php/maemo:mydicto"
 #define URL_BUGS "http://bugzilla.tal.org/"
+#define PAYPAL_URL "https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=EHQCWLH6E4U5N&lc=FI&item_name=tal%2eorg&item_number=mydicto&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_LG%2egif%3aNonHosted"
 
 static gboolean
 mydicto_about_cb()
@@ -202,11 +202,11 @@ he_about_dialog_present(GTK_WINDOW(mapp.window),
     "mydicto",
     VERSION,
     "Dictation application",
-    "Mapper is free software, GPLv2\n"
-    "Copyright 2010 Kaj-Michael Lang <milang@tal.org>",
+    "myDicto is free software, GPLv2\n"
+    "Copyright 2010-2011 Kaj-Michael Lang <milang@tal.org>",
     URL_MYDICTO,
     URL_BUGS,
-    NULL);
+    PAYPAL_URL);
 return TRUE;
 }
 
@@ -228,6 +228,7 @@ switch (srcid) {
 		g_return_if_reached();
 	break;
 }
+mapp.src_id=srcid;
 g_object_set(mapp.dw, "dicto", mapp.d, NULL);
 }
 
@@ -241,6 +242,23 @@ if (!get_selected_id_from_selector(selector, &id, &desc))
 	return;
 }
 
+/** XXX: why do I need to do this myself, stupid gtk... */
+static gboolean
+mydicto_get_active_iter_from_id_field(GtkTreeModel *model, GtkTreeIter *iter, gint field, gint idval)
+{
+gboolean valid;
+
+valid=gtk_tree_model_get_iter_first(model, iter);
+for (;valid;valid = gtk_tree_model_iter_next(model, iter)) {
+	gint id;
+
+	gtk_tree_model_get(model, iter, field, &id, -1);
+	if (idval==id)
+		return TRUE;
+}
+return FALSE;
+}
+
 static void
 mydicto_format_cb(HildonPickerButton *button, gpointer data)
 {
@@ -254,6 +272,7 @@ if (!dicto_set_format(mapp.d, (DictoFormats)id)) {
 	hildon_banner_show_information(GTK_WIDGET(mapp.window), "", _("Failed to set recording format"));
 	return;
 }
+mapp.df[mapp.src_id]=id;
 msg=g_strdup_printf("Using format:\n%s", desc);
 hildon_banner_show_information(GTK_WIDGET(mapp.window), "", msg);
 g_free(msg);
@@ -296,6 +315,7 @@ mydicto_menu(void)
 HildonAppMenu *menu;
 HildonTouchSelector *f_selector, *src_selector;
 HildonTouchSelectorColumn *column;
+GtkTreeIter iter;
 
 menu=HILDON_APP_MENU(hildon_app_menu_new());
 
@@ -319,8 +339,12 @@ hildon_button_set_title(HILDON_BUTTON(mapp.format_button), _("Recording format")
 f_selector=hildon_touch_selector_new();
 column=hildon_touch_selector_append_column(f_selector, GTK_TREE_MODEL(mapp.formats), gtk_cell_renderer_text_new(), "text", 1, NULL);
 hildon_touch_selector_column_set_text_column(column, 1);
-hildon_picker_button_set_selector(HILDON_PICKER_BUTTON(mapp.format_button), HILDON_TOUCH_SELECTOR(f_selector));
 hildon_touch_selector_set_column_selection_mode(f_selector, HILDON_TOUCH_SELECTOR_SELECTION_MODE_SINGLE);
+
+hildon_touch_selector_unselect_all(f_selector, 0);
+if (mydicto_get_active_iter_from_id_field(GTK_TREE_MODEL(mapp.formats), &iter, 0, mapp.df[SRC_MIC])==TRUE)
+	hildon_touch_selector_select_iter(f_selector, 0, &iter, FALSE);
+hildon_picker_button_set_selector(HILDON_PICKER_BUTTON(mapp.format_button), HILDON_TOUCH_SELECTOR(f_selector));
 hildon_app_menu_append(menu, GTK_BUTTON(mapp.format_button));
 
 mapp.about_button=hildon_gtk_button_new(HILDON_SIZE_AUTO);
@@ -373,12 +397,12 @@ gtk_window_set_default_icon_name("mydicto");
 
 md->program=HILDON_PROGRAM(hildon_program_get_instance());
 
-md->dm=dicto_new_full(NOTES_BASEDIR, md->f_mic, md->sink, md->mic_src);
+md->dm=dicto_new_full(NOTES_BASEDIR, md->df[SRC_MIC], md->sink, md->mic_src);
 if (!md->dm) {
 	g_error("Failed to create microphone dicto");
 	return FALSE;
 }
-md->dp=dicto_new_full(NOTES_PHONE_BASEDIR, md->f_phone, md->sink, md->phone_src);
+md->dp=dicto_new_full(NOTES_PHONE_BASEDIR, md->df[SRC_PHONE], md->sink, md->phone_src);
 if (!md->dp) {
 	g_error("Failed to create phone dicto");
 	return FALSE;
@@ -421,11 +445,34 @@ gtk_widget_show_all(GTK_WIDGET(md->window));
 return TRUE;
 }
 
+static gint
+mydicto_gconf_get_int(GConfClient *c, gchar *p, gint def)
+{
+GError *error=NULL;
+gint v;
+
+v=gconf_client_get_int(c, p, &error);
+if (error==NULL)
+	return v;
+
+g_warning("GCONF: %s", error->message);
+g_error_free(error);
+return def;
+}
+
+static void
+mydicto_load_settings(MyDicto *md)
+{
+md->df[SRC_MIC]=mydicto_gconf_get_int(mapp.client, MYDICTO_GCONF_AUDIO_FORMAT_MIC, FORMAT_WAV_8K_16B_M);
+md->df[SRC_PHONE]=mydicto_gconf_get_int(mapp.client, MYDICTO_GCONF_AUDIO_FORMAT_PHONE, FORMAT_WAV_22K_16B_M);
+
+g_debug("LMICF: %d", md->df[SRC_MIC]);
+g_debug("LPHOF: %d", md->df[SRC_PHONE]);
+}
+
 gint 
 main(gint argc, gchar * argv[])
 {
-GConfClient *client;
-
 bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
 bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 textdomain(GETTEXT_PACKAGE);
@@ -437,38 +484,26 @@ gtk_init(&argc, &argv);
 #endif
 gst_init(&argc, &argv);
 
-mapp.f_mic=FORMAT_WAV_8K_16B_M;
-mapp.f_phone=FORMAT_WAV_22K_16B_M;
+mapp.df[SRC_PHONE]=FORMAT_WAV_22K_16B_M;
+mapp.df[SRC_MIC]=FORMAT_WAV_22K_16B_M;
+
 mapp.sink=AUDIO_SINK;
 mapp.mic_src=AUDIO_SRC;
 mapp.phone_src=PHONE_SRC;
+mapp.src_id=SRC_MIC;
+
+mapp.client=gconf_client_get_default();
+
+mydicto_load_settings(&mapp);
+
 
 /* Veeery simple argument passing, mainly for getting working sinks under sdk */
 if (argc>1) {
-	mapp.f_mic=mapp.f_phone=atoi(argv[1]);
+	mapp.df[SRC_PHONE]=mapp.df[SRC_MIC]=atoi(argv[1]);
 	if (argc>2)
 		mapp.mic_src=argv[2];
 	if (argc>3)
 		mapp.sink=argv[3];
-} else {
-	GError *error=NULL;
-	gint v;
-
-	client=gconf_client_get_default();
-	v=gconf_client_get_int(client, MYDICTO_GCONF_AUDIO_FORMAT_MIC, &error);
-	if (error!=NULL) {
-		g_debug("Failed to get mic format from gconf.");
-		g_error_free(error);
-	} else {
-		mapp.f_mic=v;
-	}
-	v=gconf_client_get_int(client, MYDICTO_GCONF_AUDIO_FORMAT_PHONE, &error);
-	if (error!=NULL) {
-		g_debug("Failed to get phone format from gconf.");
-		g_error_free(error);
-	} else {
-		mapp.f_mic=v;
-	}
 }
 
 if (argc>4) {
